Crate shopping_list_parser

Crate shopping_list_parser 

Structs

Grammar
ShoppingCategory
ShoppingItem
Represents an item in the shopping list.

Enums

ParseError
Describes possible errors that can occur during shopping list parsing.
Rule

Functions

parse_shopping_list
Parses a shopping list from a given string input.