Structs
- Grammar
- Shopping
Category - Shopping
Item - Represents an item in the shopping list.
Enums
- Parse
Error - Describes possible errors that can occur during shopping list parsing.
- Rule
Functions
- parse_
shopping_ list - Parses a shopping list from a given string input.